@@ -8,13 +8,13 @@
 # granted to it by virtue of its status as an Intergovernmental Organization  #
 # or submit itself to any jurisdiction.                                       #
 ###############################################################################
-from io import BytesIO
 import os
+import subprocess
+from io import BytesIO
 from os.path import isfile, join
 
-from click.testing import CliRunner
 import pytest
-import subprocess
+from click.testing import CliRunner
 
 from LbAPLocal.cli import main
 
@@ -140,7 +140,8 @@ def with_mock_reproduce(mocker, with_data):
         },
     )
 
-    from requests import Response, get as original_get
+    from requests import Response
+    from requests import get as original_get
 
     prod_conf_data = (
         "from ProdConf import ProdConf\n"
